@@ -7,6 +7,7 @@ OC.L10N.register(
     "Select all" : "Označi sve",
     "New" : "Novo",
     "New folder" : "Nova fascikla",
+    "Search" : "Search",
     "Rename folder" : "Preimenuj fasciklu",
     "Delete folder" : "Izbriši fasciklu",
     "Cancel" : "Otkaži",
@@ -17,7 +18,6 @@ OC.L10N.register(
     "Title" : "Naslov",
     "Link" : "Veza",
     "Notes" : "Notes",
-    "Open file" : "Otvori Datoteku",
     "Owner" : "Vlasnik",
     "Sharing" : "Dijeljenje",
     "Share link" : "Podijelite vezu",
