@@ -3,35 +3,36 @@ OC.L10N.register(
     {
     "Details" : "Detalles",
     "Rename" : "Renombrar",
+    "Copy link" : "Copiar liga",
     "Move" : "Mover",
     "Delete" : "Borrar",
+    "Select all" : "Seleccionar todo",
+    "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
-    "Grid view" : "Vista de cuadrícula",
-    "List view" : "Vista de lista",
-    "Select all" : "Seleccionar todo",
+    "Search" : "Buscar",
+    "Delete folder" : "Borrar carpeta",
+    "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
+    "Shared with you" : "Compartido con usted",
+    "Files" : "Archivos",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "Recently added" : "Agregado recientemente",
-    "Alphabetically" : "Alfabéticamente",
-    "Last modified" : "Última modificación",
     "Bookmarklet" : "Marcador a código",
-    "Clear data" : "Borrar datos",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
+    "Download file" : "Descargar archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
-    "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
-    "Select" : "Seleccionar",
+    "Allow resharing" : "Permitir volver a compartir",
     "Privacy" : "Privacidad",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
