@@ -71,6 +71,7 @@ OC.L10N.register(
     "Change to list view" : "Promijeni u prikaz popisa",
     "Copy RSS Feed of current view" : "Kopiraj sažetak događaja RSS trenutnog prikaza",
     "The RSS feed requires authentication with your Nextcloud credentials" : "Sažetak događaja RSS zahtijeva autentifikaciju s pomoću Nextcloudovih vjerodajnica",
+    "Search" : "Traži",
     "Sort by created date" : "Razvrstaj prema datumu stvaranja",
     "Sort by last modified" : "Razvrstaj prema posljednjoj izmjeni",
     "Sort by title" : "Razvrstaj prema naslovu",
@@ -139,7 +140,7 @@ OC.L10N.register(
     "Notes" : "Bilješke",
     "Notes for this bookmark …" : "Bilješke za ovu knjižnu oznaku…",
     "Archived file" : "Arhivirana datoteka",
-    "Open file" : "Otvori datoteku",
+    "Download file" : "Preuzmi datoteku",
     "Open file location" : "Otvori lokaciju datoteke",
     "Created {time} ago" : "Stvoreno prije {time}",
     "Created on {date}" : "Stvoreno {date}",
@@ -156,7 +157,6 @@ OC.L10N.register(
     "Allow editing" : "Dopusti uređivanje",
     "Allow resharing" : "Dopusti ponovno dijeljenje",
     "Remove share" : "Ukloni dijeljenje",
-    "Projects" : "Projekti",
     "Link copied" : "Poveznica je kopirana",
     "Privacy" : "Privatnost",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Knjižne oznake pokušat će pristupiti mrežnim mjestima koje dodate kako bi automatski dohvatilo više informacija o tim mrežnim mjestima.",
