@@ -10,6 +10,7 @@ OC.L10N.register(
     "Go back" : "Retornar",
     "New" : "Nove",
     "New folder" : "Nove dossier",
+    "Search" : "Cercar",
     "Rename folder" : "Renominar dossier",
     "Delete folder" : "Deler dossier",
     "Cancel" : "Cancellar",
@@ -22,7 +23,6 @@ OC.L10N.register(
     "Link" : "Ligamine",
     "Tags" : "Etiquettas",
     "Notes" : "Notas",
-    "Open file" : "Aperir file",
     "Owner" : "Owner",
     "Sharing" : "Compartente",
     "Share link" : "Compartir ligamine",
