@@ -24,6 +24,7 @@ OC.L10N.register(
     "New" : "Baru",
     "New bookmark" : "Markah baru",
     "New folder" : "Folder baru",
+    "Search" : "Cari",
     "RSS feed copied" : "Umpan RSS tersalin",
     "Add a bookmark" : "Tambahkan markah",
     "Select folder" : "Pilih folder",
@@ -38,7 +39,7 @@ OC.L10N.register(
     "Shared with you" : "Shared with you",
     "Files" : "Berkas",
     "Untagged" : "Belum ada tag",
-    "No bookmarks here" : "Tidak ada markah disini",
+    "No bookmarks here" : "Tidak ada markah di sini",
     "Import" : "Impor",
     "Export" : "Ekspor",
     "Client apps" : "Aplikasi klien",
@@ -47,7 +48,6 @@ OC.L10N.register(
     "Root folder" : "Folder akar",
     "Tags" : "Tag",
     "Notes" : "Catatan",
-    "Open file" : "Membuka berkas",
     "Owner" : "Owner",
     "Sharing" : "Berbagi",
     "Select a user or group" : "Pilih pengguna atau grup",
@@ -57,7 +57,6 @@ OC.L10N.register(
     "Create public link" : "Buat tautan publik",
     "Allow editing" : "Izinkan penyuntingan",
     "Allow resharing" : "Izinkan pembagian ulang",
-    "Projects" : "Proyek",
     "Link copied" : "Link tersalin",
     "Privacy" : "Privasi",
     "Performance" : "Performa",
