@@ -13,6 +13,7 @@ OC.L10N.register(
     "Go back" : "უკან დაბრუნება",
     "New" : "ახალი",
     "New folder" : "ახალი დირექტორია",
+    "Search" : "ძიება",
     "Add a bookmark" : "სანიშნის დამატება",
     "Rename folder" : "ფოლდერის სახელის გადარქმევა",
     "Delete folder" : "დირექტორიის გაუქმება",
@@ -29,7 +30,7 @@ OC.L10N.register(
     "Link" : "ბმული",
     "Tags" : "ტეგები",
     "Notes" : "ჩანაწერები",
-    "Open file" : "ფაილის გახსნა",
+    "Download file" : "ფაილის ჩამოტვირთვა",
     "Owner" : "მფლობელი",
     "Sharing" : "გაზიარება",
     "Share link" : "ბმულის გაზიარება",
