@@ -8,6 +8,7 @@ OC.L10N.register(
     "Delete" : "ລຶບ",
     "Select all" : "ເລືອກທັງໝົດ",
     "New folder" : "ໂຟນເດີໃຫມ່",
+    "Search" : "ຄົ້ນຫາ",
     "Sort by created date" : "ຈັດລຽງຕາມລຳດັບວັນທີສ້າງ",
     "Rename folder" : "ປ່ຽນຊືໂຟນເດີ",
     "Delete folder" : "ລຶບໂຟນເດີ",
@@ -17,6 +18,7 @@ OC.L10N.register(
     "Files" : "ຟາຍ",
     "Link" : "ລິງ",
     "Tags" : "ປ້າຍກຳກັບ",
+    "Download file" : "ດາວ ໂຫລດຟາຍ",
     "Owner" : "ເຈົ້າຂອງ",
     "Sharing" : "ການແບ່ງປັນ",
     "Share link" : "ແບ່ງປັນລິງ",
