@@ -12,6 +12,7 @@ OC.L10N.register(
     "Share folder" : "Сподели папка",
     "New" : "Ново",
     "New folder" : "Нова папка",
+    "Search" : "Барај",
     "RSS feed copied" : "RSS канал копиран",
     "Rename folder" : "Преименувај папка",
     "Delete folder" : "Избриши папка",
@@ -26,8 +27,7 @@ OC.L10N.register(
     "Link" : "Линк",
     "Tags" : "Ознаки",
     "Notes" : "Белешки",
-    "Open file" : "Отвори датотека",
-    "Projects" : "Проекти",
+    "Download file" : "Преземи датотека",
     "Owner" : "Сопственик",
     "Sharing" : "Споделување",
     "Select a user or group" : "Избери корисник или група",
@@ -41,6 +41,7 @@ OC.L10N.register(
     "Failed to save settings" : "Неуспешно зачувување на параметрите",
     "Failed to load settings" : "Неуспешно вчитување на параметрите",
     "Folder" : "Папка",
-    "Save" : "Зачувај"
+    "Save" : "Зачувај",
+    "Failed to load tags" : "Неуспешно вчитување на ознаки"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
