@@ -8,11 +8,11 @@ OC.L10N.register(
     "Delete" : "Pozmak",
     "Select all" : "Hemmesini saýlaň",
     "New folder" : "Täze papka döretmek",
+    "Search" : "Gözlemek",
     "Cancel" : "ýatyrmak",
     "Files" : "Faýllar",
     "Link" : "Baglanyşyk",
     "Tags" : "Bellikler",
-    "Open file" : "Faýl açmak",
     "Sharing" : "Paýlaşmak",
     "Share link" : "Baglanyşyk paýlaş",
     "Allow editing" : "Redaktirlemäge rugsat beriň",
