@@ -8,6 +8,7 @@ OC.L10N.register(
     "Select all" : "Select all",
     "New" : "New",
     "New folder" : "New folder",
+    "Search" : "Search",
     "Delete folder" : "Delete folder",
     "Cancel" : "Cancel",
     "Recent" : "Recent",
@@ -16,6 +17,7 @@ OC.L10N.register(
     "Link" : "Link",
     "Tags" : "Tags",
     "Notes" : "Notes",
+    "Download file" : "Download file",
     "Owner" : "Owner",
     "Sharing" : "Ulashish",
     "Share link" : "Share link",
