@@ -7,10 +7,9 @@
 
 namespace OCA\Bookmarks\Service;
 
-use fivefilters\Readability\Configuration;
-use fivefilters\Readability\ParseException;
-use fivefilters\Readability\Readability;
 use Exception;
+use fivefilters\Readability\Configuration;
+use fivefilters\Readability\Readability;
 use GuzzleHttp\Client;
 use GuzzleHttp\Psr7\Response;
 use Mimey\MimeTypes;
@@ -83,6 +82,9 @@ class CrawlService {
 	 * @throws UrlParseError
 	 */
 	public function crawl(Bookmark $bookmark): void {
+		if (!$bookmark->isWebLink()) {
+			return;
+		}
 		try {
 			$client = new Client();
 			/** @var Response $resp */
@@ -113,7 +115,12 @@ class CrawlService {
 	}
 
 	private function archiveContent(Bookmark $bookmark, Response $resp) : void {
-		$contentType = $resp->getHeader('Content-type')[0];
+		$header = $resp->getHeader('Content-type');
+		if(empty($header)) {
+			return;
+		}
+
+		$contentType = $header[0];
 		if ((bool)preg_match('#text/html#i', $contentType) === true && ($bookmark->getHtmlContent() === null || $bookmark->getHtmlContent() === '')) {
 			$config = new Configuration();
 			$config
@@ -123,8 +130,9 @@ class CrawlService {
 			$readability = new Readability($config);
 			try {
 				$readability->parse($resp->getBody());
-			} catch (ParseException $e) {
+			} catch (\Throwable $e) {
 				$this->logger->debug(get_class($e)." ".$e->getMessage()."\r\n".$e->getTraceAsString());
+				return;
 			}
 			$bookmark->setHtmlContent($readability->getContent());
 			$bookmark->setTextContent(strip_tags($readability->getContent()));
@@ -132,7 +140,12 @@ class CrawlService {
 	}
 
 	private function archiveFile(Bookmark $bookmark, Response $resp) :void {
-		$contentType = $resp->getHeader('Content-type')[0];
+		$header = $resp->getHeader('Content-type');
+		if(empty($header)) {
+			return;
+		}
+
+		$contentType = $header[0];
 		if ((bool)preg_match('#text/html#i', $contentType) === false && $bookmark->getArchivedFile() === null && (int)$resp->getHeader('Content-length')[0] < self::MAX_BODY_LENGTH) {
 			try {
 				$userFolder = $this->rootFolder->getUserFolder($bookmark->getUserId());
